@@ -1,5 +1,5 @@
 
-init <- function(formula, family, data, model, nsample){
+init <- function(formula, family, data, model, nsample, ncase, nctrl, outcome){
   
   if(!(family %in% c('gaussian', 'binomial', 'case-control'))){
     stop('family should be \'gaussian\', \'binomial\', or \'case-control\'.')
@@ -13,6 +13,10 @@ init <- function(formula, family, data, model, nsample){
     ini <- init.lo(formula, data, model, nsample)
   }
   
+  if(family == 'case-control'){
+    ini <- init.cc(formula, data, model, ncase, nctrl, outcome)
+  }
+  
   ini
   
 }
